@@ -28,8 +28,13 @@ def thread_for(id_: Optional[str], type_: str) -> dict[str, Any]:
             "subject_id": id_,
             "subject_type": type_,
             "include_comments": True,
+            "combine_comments": True,
             "include_author": True,
             "init_missing": True,
         },
     )
     return thread
+
+@helper
+def mobile_depth_threshold():
+    return tk.asint(tk.config.get(const.CONFIG_MOBILE_THRESHOLD, const.DEFAULT_MOBILE_THRESHOLD))
