@@ -109,13 +109,15 @@ def comment_delete(context, data_dict):
 
 @auth
 def comment_update(context, data_dict):
-    id = tk.get_or_bust(data_dict, "id")
+    id = data_dict.get("id")
+    if not id:
+        return {"success": False}
+
     comment = (
         context['session'].query(Comment).filter(Comment.id == id).one_or_none()
     )
-
     if not comment:
-        raise tk.ObjectNotFound("Comment not found")
+        return {"success": False}
 
     by_author = comment.is_authored_by(context["user"])
     if by_author or is_moderator(context["auth_user_obj"], comment, comment.thread):
